==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/GuardDuty/GetInvitationsCount.pm <==

package Paws::GuardDuty::GetInvitationsCount;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetInvitationsCount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/invitation/count');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GuardDuty::GetInvitationsCountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GuardDuty::GetInvitationsCount - Arguments for method GetInvitationsCount on L<Paws::GuardDuty>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetInvitationsCount on the
L<Amazon GuardDuty|Paws::GuardDuty> service. Use the attributes of this class
as arguments to method GetInvitationsCount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetInvitationsCount.

=head1 SYNOPSIS

    my $guardduty = Paws->service('GuardDuty');
    my $GetInvitationsCountResponse = $guardduty->GetInvitationsCount();

    # Results:
    my $InvitationsCount = $GetInvitationsCountResponse->InvitationsCount;

    # Returns a L<Paws::GuardDuty::GetInvitationsCountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetInvitationsCount in L<Paws::GuardDuty>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/GuardDuty/GetInvitationsCount.pm <==

package Paws::GuardDuty::GetInvitationsCount;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetInvitationsCount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/invitation/count');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GuardDuty::GetInvitationsCountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GuardDuty::GetInvitationsCount - Arguments for method GetInvitationsCount on L<Paws::GuardDuty>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetInvitationsCount on the
L<Amazon GuardDuty|Paws::GuardDuty> service. Use the attributes of this class
as arguments to method GetInvitationsCount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetInvitationsCount.

=head1 SYNOPSIS

    my $guardduty = Paws->service('GuardDuty');
    my $GetInvitationsCountResponse = $guardduty->GetInvitationsCount();

    # Results:
    my $InvitationsCount = $GetInvitationsCountResponse->InvitationsCount;

    # Returns a L<Paws::GuardDuty::GetInvitationsCountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/guardduty/GetInvitationsCount>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetInvitationsCount in L<Paws::GuardDuty>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
